%% PK Generate data
load('OptimisedParams_Step1')
[row column] = size(OptimisedParams_Step1.PHIR);

% Fixed effect
ParamTemp = OptimisedParams_Step1.PHI;
ParamTemp(ismember(paramNames,"Rb")) = 0.75; % Kleibers law
ParamTemp(ismember(paramNames,"Vb")) = 1;    % Kleibers law
ParamTemp(ismember(paramNames,"BW")) = mean(BWRats);    % Total body weight of the rats (kg)
ParamTemp(ismember(paramNames,"f"))  = 0.62;            % Rat bioaviability
ParamTemp(ismember(paramNames,"ReAdministration_Time"))    = 1440*7;  % re-administration of drug is set to once every week, which will not be triggered in a 1 day long simulation
ParamTemp(ismember(paramNames,"ReAdministration_Amount"))  = 0;       % if re-administration triggers then the state A is set to 0
initialConditions(ismember(stateNames,"A")) = 80*mean(BWRats);  % Oral administration of subX (uMol)
simRatExperiment = model(0:1:1440,initialConditions,ParamTemp);    % Simulate Oral administration
SubX_RatExperiment.FixedPK       = simRatExperiment.statevalues(:,ismember(simRatExperiment.states,'C1'));
SubX_RatExperiment.FixedHormoneX = simRatExperiment.statevalues(:,ismember(simRatExperiment.states,'HormoneX'));
SubX_RatExperiment.FixedPD       = simRatExperiment.reactionvalues(:,ismember(simRatExperiment.reactions,'SubX_PD'));

% Subject-specific
for i = 1:10 % Simulate 10 rats
ParamTemp = OptimisedParams_Step1.PHIR (i,:);
ParamTemp(ismember(paramNames,"BW")) = BWRats(i);  % Total body weight of the rats (kg)
ParamTemp(ismember(paramNames,"Rb")) = 0.75;       % Kleibers law
ParamTemp(ismember(paramNames,"Vb")) = 1;          % Kleibers law
ParamTemp(ismember(paramNames,"f"))  = 0.62;       % Rat bioaviability
ParamTemp(ismember(paramNames,"ReAdministration_Time"))    = 1440*7;  % re-administration of drug is set to once every week, which will not be triggered in a 1 day long simulation
ParamTemp(ismember(paramNames,"ReAdministration_Amount"))  = 0;       % if re-administration triggers then the state A is set to 0
initialConditions(ismember(stateNames,"A")) = 80*BWRats(i);           % Oral administration of subX (uMol)

simRatExperiment = model(0:1:1440,initialConditions,ParamTemp); % Simulate Oral administration

SubX_RatExperiment.PK(i,:)       = simRatExperiment.statevalues(:,ismember(simRatExperiment.states,'C1'));
SubX_RatExperiment.HormoneX(i,:) = simRatExperiment.statevalues(:,ismember(simRatExperiment.states,'HormoneX'));
SubX_RatExperiment.PD(i,:)       = simRatExperiment.reactionvalues(:,ismember(simRatExperiment.reactions,'SubX_PD'));

end
SubX_RatExperiment.time       = simRatExperiment.time(:);

%%  PK Plot
figure('units','normalized','outerposition',[0 0 1 1])

% PK
subplot(1,3,1)
hold on
set(gca,'xtick',0:6:24,'ytick',[0.1,1,10,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log')
title('Pharmacokinetics')
for i=1:10
plot(SubX_RatExperiment.time/60, SubX_RatExperiment.PK(i,:),'Color',colorID{i},'LineWidth',2)
end
plot(SubX_RatExperiment.time/60, SubX_RatExperiment.FixedPK,'k','LineWidth',4)
plot(SubX1_data.time/60, SubX1_data.PKRat1,'.','Color',colorID{1},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.PKRat2,'.','Color',colorID{2},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.PKRat3,'.','Color',colorID{3},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.PKRat4,'.','Color',colorID{4},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.PKRat5,'.','Color',colorID{5},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.PKRat6,'.','Color',colorID{6},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.PKRat7,'.','Color',colorID{7},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.PKRat8,'.','Color',colorID{8},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.PKRat9,'.','Color',colorID{9},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.PKRat10,'.','Color',colorID{10},'MarkerSize',20)
line([0 0.5], [0.01 0.01],'Color','k','LineWidth',8);
ylabel({'SubX'; strcat('(',char(181),'Mol/L)')});
xlabel({'Time (min)'});
ylim( [0.01 150])
xlim( [0 25])
legend('Rat 1','Rat 2','Rat 3','Rat 4','Rat 5','Rat 6','Rat 7','Rat 8','Rat 9','Rat 10','Fixed effect')
grid on
hold off

% PD
subplot(1,3,2)
hold on
set(gca,'xtick',0:6:24,'ytick',0:25:125,'FontSize', 20,'FontSmoothing','on','fontname','Arial')
title('Pharmacodynamics')
for i=1:10
plot(SubX_RatExperiment.time/60, SubX_RatExperiment.HormoneX(i,:),'Color',colorID{i},'LineWidth',2)
end
plot(SubX_RatExperiment.time/60, SubX_RatExperiment.FixedHormoneX,'k','LineWidth',4)
plot(SubX1_data.time/60, SubX1_data.NormPDRat1,'.','Color',colorID{1},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat2,'.','Color',colorID{2},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat3,'.','Color',colorID{3},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat4,'.','Color',colorID{4},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat5,'.','Color',colorID{5},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat6,'.','Color',colorID{6},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat7,'.','Color',colorID{7},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat8,'.','Color',colorID{8},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat9,'.','Color',colorID{9},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat10,'.','Color',colorID{10},'MarkerSize',20)
line([0 0.5], [0.01 0.01],'Color','k','LineWidth',8);
ylabel({'Hormone (%)'});
xlabel({'Time (min)'});
xlim( [0 25])
ylim( [0 125])
grid on
hold off

% PKPD
subplot(1,3,3)
hold on
set(gca,'xtick',[0.1,1,10,100],'ytick',0:2:20,'FontSize', 20,'FontSmoothing','on','fontname','Arial','XScale','log')
title('PKPD curve')
for i=1:10
plot(SubX_RatExperiment.PK(i,:), SubX_RatExperiment.PD(i,:),'Color',colorID{i},'LineWidth',2)
end
plot(SubX_RatExperiment.FixedPK, SubX_RatExperiment.FixedPD,'k','LineWidth',4)
xlabel(strcat('Pharmacokinetics: SubX (',char(181),'Mol/L)'));
ylabel({'Pharmacodynamics'; 'Increase from vehicle (ratio)'});
xlim( [0.1 200])
ylim( [0 15])
grid on
hold off

%% Parameter random effect correlation with eatchother
figure()

hold on
RHO = corrcov(OptimisedParams_Step1.PSI);
clf; 
imagesc(RHO)
set(gca,'XTick',[1 2],'YTick',[1 2])
title('{\bf Random Effect Correlation}')
h = colorbar;
set(get(h,'YLabel'),'String','Correlation');
ylabel({'Parameter random effect'});
xlabel({'Parameter random effect'});
hold off

%% Population parameter distribution
figure('units','normalized','outerposition',[0 0 1 1])

for i=1:8
    set(gca,'ytick',0:2:10,'FontSmoothing','on','fontname','Arial')
hold on
    subplot(2,4,i)
    if std(OptimisedParams_Step1.PHIR(:,i)) > 1e-10 % remove numerical errors
     h = histfit(OptimisedParams_Step1.PHIR(:,i),10,'normal');
      h(1).FaceColor = [0, 0.5, 0.9];
      h(2).Color  = [0.6350, 0.0780, 0.1840];
    else
        bar(mean(OptimisedParams_Step1.PHIR(:,i)),10,0.1*mean(OptimisedParams_Step1.PHIR(:,i)));
        xlim([0, 2*mean(OptimisedParams_Step1.PHIR(:,i))])
    end
        title(strcat("Parameter " ,int2str(i),':','', paramNames(i)))
ylabel({'Parameters with that value'});
xlabel({'Parameter value'});
ylim( [0 11])
hold off
grid on
end