%% PK RAT

for i = 1:10 % Simulate 10 rats
ParamTemp = paramValues;
ParamTemp(ismember(paramNames,"BW"))  = BWRats(i);   % Total body weight of the rats (kg)
ParamTemp(ismember(paramNames,"f")) = 0.62;  % Bioaviability
ParamTemp(ismember(paramNames,"Rb")) = 0.75; % Kleibers law
ParamTemp(ismember(paramNames,"Vb")) = 1;    % Kleibers law
initialConditions(ismember(stateNames,"A")) = 80*BWRats(i);                % Oral administration of subX (uMol)

simRatExperiment = model(0:1:1440,initialConditions,ParamTemp); % Simulate Oral administration

SubX_RatExperiment.PK(i,:)       = simRatExperiment.statevalues(:,ismember(simRatExperiment.states,'C1'));%.*lognrnd(0,0.1,25,1);
SubX_RatExperiment.HormoneX(i,:) = simRatExperiment.statevalues(:,ismember(simRatExperiment.states,'HormoneX'));%.*lognrnd(0,0.05,25,1);
SubX_RatExperiment.PD(i,:)       = simRatExperiment.reactionvalues(:,ismember(simRatExperiment.reactions,'SubX_PD'));

end
SubX_RatExperiment.time       = simRatExperiment.time(:);

%%  Plot
figure('units','normalized','outerposition',[0 0 1 1])

% PK oral
subplot(1,2,1)
hold on
set(gca,'xtick',0:6:24,'ytick',[0.1,1,10,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log')
title('Pharmacokinetics')
for i=1:10
plot(SubX_RatExperiment.time/60, SubX_RatExperiment.PK(i,:),'Color',colorID{i},'LineWidth',2)
end
line([0 0.5], [0.01 0.01],'Color','k','LineWidth',8);
plot(SubX1_data.time/60, SubX1_data.PKRat1,'.','Color',colorID{1},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat2,'.','Color',colorID{2},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat3,'.','Color',colorID{3},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat4,'.','Color',colorID{4},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat5,'.','Color',colorID{5},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat6,'.','Color',colorID{6},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat7,'.','Color',colorID{7},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat8,'.','Color',colorID{8},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat9,'.','Color',colorID{9},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat10,'.','Color',colorID{10},'MarkerSize',25)
ylabel({'SubX'; strcat('(',char(181),'Mol/L)')});
xlabel({'Time (min)'});
ylim( [0.01 200])
xlim( [0 25])
legend('Rat 1','Rat 2','Rat 3','Rat 4','Rat 5','Rat 6','Rat 7','Rat 8','Rat 9','Rat 10')
grid on
hold off

% PD oral
subplot(1,2,2)
hold on
set(gca,'xtick',0:6:24,'ytick',0:25:125,'FontSize', 20,'FontSmoothing','on','fontname','Arial')
line([0 0.5], [0 0],'Color','k','LineWidth',8);
title('Pharmacodynamics')
for i=1:10
plot(SubX_RatExperiment.time/60, SubX_RatExperiment.HormoneX(i,:),'Color',colorID{i},'LineWidth',2)
end
plot(SubX1_data.time/60, SubX1_data.NormPDRat1,'.','Color',colorID{1},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.NormPDRat2,'.','Color',colorID{2},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.NormPDRat3,'.','Color',colorID{3},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.NormPDRat4,'.','Color',colorID{4},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.NormPDRat5,'.','Color',colorID{5},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.NormPDRat6,'.','Color',colorID{6},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.NormPDRat7,'.','Color',colorID{7},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.NormPDRat8,'.','Color',colorID{8},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.NormPDRat9,'.','Color',colorID{9},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.NormPDRat10,'.','Color',colorID{10},'MarkerSize',25)
ylabel({'Hormone (%)'});
xlabel({'Time (min)'});
xlim( [0 25])
ylim( [0 125])
grid on
hold off

%%  PKPD plot
figure('units','normalized','outerposition',[0 0 1 1])

% PK oral
hold on
set(gca,'xtick',[0.1,1,10,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','XScale','log')
title('PKPD curve')
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
for i=1:10
plot(SubX_RatExperiment.PK(i,:), SubX_RatExperiment.PD(i,:),'Color',colorID{i},'LineWidth',2)
end
xlabel(strcat('SubX (',char(181),'Mol/L)'));
ylabel({'Drug effect'; 'increase from vehicle (ratio)'});
xlim( [0.1 150])
grid on
hold off