%% Load parameters

load('OptimisedParams_Step2')

MonkeyBW = 4.31;
DogBW    = 9.725;
IndexBW  = [BWRats,MonkeyBW,DogBW];
IndexDose  = 80*IndexBW; % 80 umol/kg to umol
Bioavailability = [0.62,0.62,0.62,0.62,0.62,0.62,0.62,0.62,0.62,0.62,0.77,0.52];

SpeciesParameters = OptimisedParams_Step2.PHIR;
SpeciesParameters(:,ismember(paramNames,"BW"))  = IndexBW';
SpeciesParameters(:,ismember(paramNames,"f"))   = Bioavailability';
SpeciesParameters(:,ismember(paramNames,"ReAdministration_Time"))    = 1440*7;  % re-administration of drug is set to once every week, which will not be triggered in a 1 day long simulation
SpeciesParameters(:,ismember(paramNames,"ReAdministration_Amount"))  = 0;       % if re-administration triggers then the state A is set to 0

SpeciesStates      = repmat(initialConditions',12,1);
SpeciesStates(:,ismember(stateNames,"A"))  = IndexDose';

WeightPlotVector = 0.1:0.1:100;

%% Collect uncertainty

for i = 1:length(IndexBW)

simSpecies   = model(0:1:1440,SpeciesStates(i,:),SpeciesParameters(i,:));

SubX_MetabolicTranslation.PK(i,:)       = simSpecies.statevalues(:,ismember(simSpecies.states,'C1'));
SubX_MetabolicTranslation.HormoneX(i,:) = simSpecies.statevalues(:,ismember(simSpecies.states,'HormoneX'));
SubX_MetabolicTranslation.PD(i,:)       = simSpecies.reactionvalues(:,ismember(simSpecies.reactions,'SubX_PD'));
SubX_MetabolicTranslation.CL(i,1)       = simSpecies.variablevalues(1,ismember(simSpecies.variables,'CL'));
SubX_MetabolicTranslation.V1(i,1)       = simSpecies.variablevalues(1,ismember(simSpecies.variables,'V1'));

end

Translation_cl  = OptimisedParams_Step2.PHI(ismember(paramNames,"CLref")) .*(WeightPlotVector./0.3).^OptimisedParams_Step2.PHI(ismember(paramNames,"Rb"));
Translation_vd  = OptimisedParams_Step2.PHI(ismember(paramNames,"V1ref")) .*(WeightPlotVector./0.3).^OptimisedParams_Step2.PHI(ismember(paramNames,"Vb"));

SubX_MetabolicTranslation.time  = simSpecies.time;

%%  PK plot
figure('units','normalized','outerposition',[0 0 1 1])

% PK oral
subplot(1,3,1)
hold on
set(gca,'xtick',0:6:24,'ytick',[0.1,1,10,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log')
title('Rat')
for i=1:10
plot(SubX_MetabolicTranslation.time/60, SubX_MetabolicTranslation.PK(i,:),'Color',colorID{i},'LineWidth',4)
end
plot(SubX1_data.time/60, SubX1_data.PKRat1,'.','Color',colorID{1},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat2,'.','Color',colorID{2},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat3,'.','Color',colorID{3},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat4,'.','Color',colorID{4},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat5,'.','Color',colorID{5},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat6,'.','Color',colorID{6},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat7,'.','Color',colorID{7},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat8,'.','Color',colorID{8},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat9,'.','Color',colorID{9},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat10,'.','Color',colorID{10},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat9,'.','Color',colorID{9},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat10,'.','Color',colorID{10},'MarkerSize',25)
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
ylabel({'SubX'; strcat('(',char(181),'Mol/L)')});
xlabel({'Time (min)'});
ylim( [0.01 500])
xlim( [0 25])
legend('Rat 1','Rat 2','Rat 3','Rat 4','Rat 5','Rat 6','Rat 7','Rat 8','Rat 9','Rat 10')
grid on
hold off
% PK oral
subplot(1,3,2)
hold on
title('Monkey')
set(gca,'xtick',0:6:24,'ytick',[0.1,1,10,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log')
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
plot(SubX_MetabolicTranslation.time/60, SubX_MetabolicTranslation.PK(11,:),'Color',colorID{11},'LineWidth',4)
plot(SubX1_data.time/60, SubX1_data.Monkey,'.','Color',colorID{11},'MarkerSize',25)
ylabel({'SubX'; strcat('(',char(181),'Mol/L)')});
xlabel({'Time (min)'});
ylim( [0.01 500])
xlim( [0 25])
grid on
hold off
% PK oral
subplot(1,3,3)
hold on
set(gca,'xtick',0:6:24,'ytick',[0.1,1,10,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log')
title('Dog')
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
plot(SubX_MetabolicTranslation.time/60, SubX_MetabolicTranslation.PK(12,:),'Color',colorID{12},'LineWidth',4)
plot(SubX1_data.time/60, SubX1_data.Dog,'.','Color',colorID{12},'MarkerSize',25)
ylabel({'SubX'; strcat('(',char(181),'Mol/L)')});
xlabel({'Time (min)'});
ylim( [0.01 500])
xlim( [0 25])
grid on
hold off

%% PD
figure('units','normalized','outerposition',[0 0 1 1])

subplot(1,3,1)
hold on
set(gca,'xtick',0:6:24,'ytick',0:25:100,'FontSize', 20,'FontSmoothing','on','fontname','Arial')
title('Rat')
for i=1:10
plot(SubX_MetabolicTranslation.time/60, SubX_MetabolicTranslation.HormoneX(i,:),'Color',colorID{i},'LineWidth',4)
end
plot(SubX1_data.time/60, SubX1_data.NormPDRat1,'.','Color',colorID{1},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat2,'.','Color',colorID{2},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat3,'.','Color',colorID{3},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat4,'.','Color',colorID{4},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat5,'.','Color',colorID{5},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat6,'.','Color',colorID{6},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat7,'.','Color',colorID{7},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat8,'.','Color',colorID{8},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat9,'.','Color',colorID{9},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat10,'.','Color',colorID{10},'MarkerSize',20)
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
ylabel({'Hormone'; '(%)'});
xlabel({'Time (min)'});
xlim( [0 25])
ylim( [0 125])
legend('Rat 1','Rat 2','Rat 3','Rat 4','Rat 5','Rat 6','Rat 7','Rat 8','Rat 9','Rat 10')
grid on
hold off
subplot(1,3,2)
hold on
set(gca,'xtick',0:6:24,'ytick',0:25:100,'FontSize', 20,'FontSmoothing','on','fontname','Arial')
title('Monkey')
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
plot(SubX_MetabolicTranslation.time/60, SubX_MetabolicTranslation.HormoneX(11,:),'Color',colorID{11},'LineWidth',4)
plot(SubX1_data.time/60, SubX1_data.NormPDMonkey,'.','Color',colorID{11},'MarkerSize',40)
ylabel({'Hormone'; '(%)'});
xlabel({'Time (min)'});
xlim( [0 25])
ylim( [0 125])
grid on
hold off
subplot(1,3,3)
hold on
set(gca,'xtick',0:6:24,'ytick',0:25:100,'FontSize', 20,'FontSmoothing','on','fontname','Arial')
title('Dog')
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
plot(SubX_MetabolicTranslation.time/60, SubX_MetabolicTranslation.HormoneX(12,:),'Color',colorID{12},'LineWidth',4)
plot(SubX1_data.time/60, SubX1_data.NormPDDog,'.','Color',colorID{12},'MarkerSize',40)
ylabel({'Hormone'; '(%)'});
xlabel({'Time (min)'});
xlim( [0 25])
ylim( [0 125])
grid on
hold off

%% PKPD
figure()

hold on
set(gca,'xtick',[0.1,1,10,100],'ytick',0:2:20,'FontSize', 20,'FontSmoothing','on','fontname','Arial','XScale','log')
title('PKPD curve')
for i=1:12
plot(SubX_MetabolicTranslation.PK(i,:), SubX_MetabolicTranslation.PD(i,:),'Color',colorID{i},'LineWidth',2)
end
xlabel(strcat('Pharmacokinetics: SubX (',char(181),'Mol/L)'));
ylabel({'Pharmacodynamics'; 'Increase from vehicle (ratio)'});
xlim( [0.1 200])
ylim( [0 15])
grid on
hold off

%% Parameter random effect correlation with eatchother
figure()

hold on
RHO = corrcov(OptimisedParams_Step2.PSI);
clf; 
imagesc(RHO)
set(gca,'XTick',[1 2],'YTick',[1 2])
title('{\bf Random Effect Correlation}')
h = colorbar;
set(get(h,'YLabel'),'String','Correlation');
ylabel({'Parameter random effect'});
xlabel({'Parameter random effect'});
hold off

%% Population parameter distribution
figure('units','normalized','outerposition',[0 0 1 1])

for i=1:8
    set(gca,'ytick',0:2:12,'FontSmoothing','on','fontname','Arial')
hold on
    subplot(2,4,i)
    if std(OptimisedParams_Step2.PHIR(:,i)) > 1e-10 % remove numerical errors
     h = histfit(OptimisedParams_Step2.PHIR(:,i),10,'normal');
      h(1).FaceColor = [0, 0.5, 0.9];
      h(2).Color  = [0.6350, 0.0780, 0.1840];
    else
        bar(mean(OptimisedParams_Step2.PHIR(:,i)),12,0.1*mean(OptimisedParams_Step2.PHIR(:,i)));
        xlim([0, 2*mean(OptimisedParams_Step2.PHIR(:,i))])
    end
        title(strcat("Parameter " ,int2str(i),':','', paramNames(i)))
ylabel({'Parameters with that value'});
xlabel({'Parameter value'});
ylim( [0 13])
hold off
grid on
end

%% Metabolic translation
figure('units','normalized','outerposition',[0 0 1 1])

% PD oral
subplot(1,3,1)
hold on
set(gca,'xtick',[0.1,1,10,100],'ytick',[0.0001,0.01,1,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log','XScale','log')
title('Initial guess for clearance')
plot(WeightPlotVector,Translation_cl,'--','Color', colorID{1},'LineWidth',2);
 for i=1:12
plot(IndexBW(i), SubX_MetabolicTranslation.CL(i,1),'.','Color',colorID{i},'MarkerSize',25)
 end
text(0.2,0.0005,'Rats (N=10)','FontSize', 20,'FontSmoothing','on') 
text(2,0.012,'Monkey','FontSize', 20,'FontSmoothing','on') 
text(7,0.02,'Dog','FontSize', 20,'FontSmoothing','on') 
ylabel({'Rate of clearance' ; '(1/min)'});
xlabel({'Weight (kg)'});
xlim( [0.09 100])
ylim( [0.0001 125])
grid on
hold off

% PD oral
subplot(1,3,2)
hold on
set(gca,'xtick',[0.1,1,10,100],'ytick',[0.0001,0.01,1,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log','XScale','log')
title('Initial guess for volume')
plot(WeightPlotVector,Translation_vd,'--','Color', colorID{1},'LineWidth',2);
 for i=1:12
plot(IndexBW(i), SubX_MetabolicTranslation.V1(i,1),'.','Color',colorID{i},'MarkerSize',25)
 end
text(0.2,0.02,'Rats (N=10)','FontSize', 20,'FontSmoothing','on') 
text(2,1,'Monkey','FontSize', 20,'FontSmoothing','on') 
text(7,2,'Dog','FontSize', 20,'FontSmoothing','on') 
ylabel({'Volume scaling' ; '(L)'});
xlabel({'Weight (kg)'});
xlim( [0.09 100])
ylim( [0.0001 125])
grid on
hold off

% PD oral
subplot(1,3,3)
hold on
set(gca,'xtick',[0.1,1,10,100],'ytick',[0.0001,0.01,1,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log','XScale','log')
title('Initial guess for potency')
yline(OptimisedParams_Step2.PHI(ismember(paramNames,"EC50")),'--','Color', colorID{1},'LineWidth',2);
 for i=1:12
plot(IndexBW(i), SpeciesParameters(i,ismember(paramNames,"EC50")),'.','Color',colorID{i},'MarkerSize',25)
 end
text(0.1,1.5*max(SpeciesParameters(:,ismember(paramNames,"EC50"))),'Rats (N=10)','FontSize', 20,'FontSmoothing','on') 
text(1.9,0.8*min(SpeciesParameters(:,ismember(paramNames,"EC50"))),'Monkey','FontSize', 20,'FontSmoothing','on') 
text(7,1.5*max(SpeciesParameters(:,ismember(paramNames,"EC50"))),'Dog','FontSize', 20,'FontSmoothing','on') 
ylabel({'Volume scaling' ; '(L)'});
xlabel({'Weight (kg)'});
xlim( [0.09 100])
ylim( [0.0001 125])
grid on
hold off
