%% Declare Body weight information

MonkeyBW = 4.31;
DogBW    = 9.725;
IndexBW  = [BWRats,MonkeyBW,DogBW];
IndexDose  = 80*IndexBW; % 80 umol/kg to umol
Bioavailability = [0.62,0.62,0.62,0.62,0.62,0.62,0.62,0.62,0.62,0.62,0.77,0.52];

load('OptimisedParams_Step1')

SpeciesParameters = repmat(OptimisedParams_Step1.PHI,12,1);
SpeciesParameters(1:10,:)  = OptimisedParams_Step1.PHIR;
SpeciesParameters(:,ismember(paramNames,"BW"))  = IndexBW';
SpeciesParameters(:,ismember(paramNames,"f"))   = Bioavailability';
SpeciesParameters(:,ismember(paramNames,"Rb")) = 0.75;  % Keibers law
SpeciesParameters(:,ismember(paramNames,"Vb"))  = 1;     % Keibers law
SpeciesParameters(:,ismember(paramNames,"ReAdministration_Time"))    = 1440*7;  % re-administration of drug is set to once every week, which will not be triggered in a 1 day long simulation
SpeciesParameters(:,ismember(paramNames,"ReAdministration_Amount"))  = 0;       % if re-administration triggers then the state A is set to 0

SpeciesStates      = repmat(initialConditions',12,1);
SpeciesStates(:,ismember(stateNames,"A"))  = IndexDose';

%% PK Generate data

WeightPlotVector = 0.1:0.1:100;

for i = 1:length(IndexBW)

simSpecies   = model(0:1:1440,SpeciesStates(i,:),SpeciesParameters(i,:));

SubX_MetabolicTranslation.PK(i,:) = simSpecies.statevalues(:,ismember(simSpecies.states,'C1'));
SubX_MetabolicTranslation.PD(i,:) = simSpecies.statevalues(:,ismember(simSpecies.states,'HormoneX'));
SubX_MetabolicTranslation.CL(i,1) = simSpecies.variablevalues(1,ismember(simSpecies.variables,'CL'));
SubX_MetabolicTranslation.V1(i,1) = simSpecies.variablevalues(1,ismember(simSpecies.variables,'V1'));

Translation_cl(i,:)  = SpeciesParameters(i,ismember(paramNames,"CLref")) .*(WeightPlotVector./0.3).^SpeciesParameters(i,ismember(paramNames,"Rb"));
Translation_vd(i,:)  = SpeciesParameters(i,ismember(paramNames,"V1ref")) .*(WeightPlotVector./0.3).^SpeciesParameters(i,ismember(paramNames,"Vb"));
end
SubX_MetabolicTranslation.time  = simSpecies.time;
%%  PK plot
figure('units','normalized','outerposition',[0 0 1 1])

% PK oral
subplot(1,3,1)
hold on
set(gca,'xtick',0:6:24,'ytick',[0.1,1,10,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log')
title('Rat')
for i=1:10
plot(SubX_MetabolicTranslation.time/60, SubX_MetabolicTranslation.PK(i,:),'Color',colorID{i},'LineWidth',4)
end
plot(SubX1_data.time/60, SubX1_data.PKRat1,'.','Color',colorID{1},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat2,'.','Color',colorID{2},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat3,'.','Color',colorID{3},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat4,'.','Color',colorID{4},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat5,'.','Color',colorID{5},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat6,'.','Color',colorID{6},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat7,'.','Color',colorID{7},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat8,'.','Color',colorID{8},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat9,'.','Color',colorID{9},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat10,'.','Color',colorID{10},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat9,'.','Color',colorID{9},'MarkerSize',25)
plot(SubX1_data.time/60, SubX1_data.PKRat10,'.','Color',colorID{10},'MarkerSize',25)
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
ylabel({'SubX'; strcat('(',char(181),'Mol/L)')});
xlabel({'Time (min)'});
ylim( [0.01 500])
xlim( [0 25])
legend('Rat 1','Rat 2','Rat 3','Rat 4','Rat 5','Rat 6','Rat 7','Rat 8','Rat 9','Rat 10')
grid on
hold off
% PK oral
subplot(1,3,2)
hold on
title('Monkey')
set(gca,'xtick',0:6:24,'ytick',[0.1,1,10,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log')
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
plot(SubX_MetabolicTranslation.time/60, SubX_MetabolicTranslation.PK(11,:),'Color',colorID{11},'LineWidth',4)
plot(SubX1_data.time/60, SubX1_data.Monkey,'.','Color',colorID{11},'MarkerSize',25)
ylabel({'SubX'; strcat('(',char(181),'Mol/L)')});
xlabel({'Time (min)'});
ylim( [0.01 500])
xlim( [0 25])
grid on
hold off
% PK oral
subplot(1,3,3)
hold on
set(gca,'xtick',0:6:24,'ytick',[0.1,1,10,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log')
title('Dog')
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
plot(SubX_MetabolicTranslation.time/60, SubX_MetabolicTranslation.PK(12,:),'Color',colorID{12},'LineWidth',4)
plot(SubX1_data.time/60, SubX1_data.Dog,'.','Color',colorID{12},'MarkerSize',25)
ylabel({'SubX'; strcat('(',char(181),'Mol/L)')});
xlabel({'Time (min)'});
ylim( [0.01 500])
xlim( [0 25])
grid on
hold off

%% PD
figure('units','normalized','outerposition',[0 0 1 1])

subplot(1,3,1)
hold on
set(gca,'xtick',0:6:24,'ytick',0:25:100,'FontSize', 20,'FontSmoothing','on','fontname','Arial')
title('Rat')
for i=1:10
plot(SubX_MetabolicTranslation.time/60, SubX_MetabolicTranslation.PD(i,:),'Color',colorID{i},'LineWidth',4)
end
plot(SubX1_data.time/60, SubX1_data.NormPDRat1,'.','Color',colorID{1},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat2,'.','Color',colorID{2},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat3,'.','Color',colorID{3},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat4,'.','Color',colorID{4},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat5,'.','Color',colorID{5},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat6,'.','Color',colorID{6},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat7,'.','Color',colorID{7},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat8,'.','Color',colorID{8},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat9,'.','Color',colorID{9},'MarkerSize',20)
plot(SubX1_data.time/60, SubX1_data.NormPDRat10,'.','Color',colorID{10},'MarkerSize',20)
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
ylabel({'Hormone'; '(%)'});
xlabel({'Time (min)'});
xlim( [0 25])
ylim( [0 125])
legend('Rat 1','Rat 2','Rat 3','Rat 4','Rat 5','Rat 6','Rat 7','Rat 8','Rat 9','Rat 10')
grid on
hold off
subplot(1,3,2)
hold on
set(gca,'xtick',0:6:24,'ytick',0:25:100,'FontSize', 20,'FontSmoothing','on','fontname','Arial')
title('Monkey')
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
plot(SubX_MetabolicTranslation.time/60, SubX_MetabolicTranslation.PD(11,:),'Color',colorID{11},'LineWidth',4)
plot(SubX1_data.time/60, SubX1_data.NormPDMonkey,'.','Color',colorID{11},'MarkerSize',40)
ylabel({'Hormone'; '(%)'});
xlabel({'Time (min)'});
xlim( [0 25])
ylim( [0 125])
grid on
hold off
subplot(1,3,3)
hold on
set(gca,'xtick',0:6:24,'ytick',0:25:100,'FontSize', 20,'FontSmoothing','on','fontname','Arial')
title('Dog')
line([0 0.5], [0.1 0.1],'Color','k','LineWidth',8);
plot(SubX_MetabolicTranslation.time/60, SubX_MetabolicTranslation.PD(12,:),'Color',colorID{12},'LineWidth',4)
plot(SubX1_data.time/60, SubX1_data.NormPDDog,'.','Color',colorID{12},'MarkerSize',40)
ylabel({'Hormone'; '(%)'});
xlabel({'Time (min)'});
xlim( [0 25])
ylim( [0 125])
grid on
hold off

%% Metabolic translation
figure('units','normalized','outerposition',[0 0 1 1])

% PD oral
subplot(1,3,1)
hold on
set(gca,'xtick',[0.1,1,10,100],'ytick',[0.0001,0.01,1,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log','XScale','log')
title('Clearance')
fill([WeightPlotVector(1), WeightPlotVector(end),WeightPlotVector(end),WeightPlotVector(1)],[max(Translation_cl(:,1)) max(Translation_cl(:,end)) min(Translation_cl(:,end)) min(Translation_cl(:,1))], colorID{1},'FaceAlpha',1,'EdgeAlpha',1);
 for i=1:12
plot(IndexBW(i), SubX_MetabolicTranslation.CL(i,1),'.','Color',colorID{i},'MarkerSize',25)
 end
text(0.2,0.0005,'Rats (N=10)','FontSize', 20,'FontSmoothing','on') 
text(2,0.012,'Monkey guess','FontSize', 20,'FontSmoothing','on') 
text(7,0.02,'Dog guess','FontSize', 20,'FontSmoothing','on') 
ylabel({'Rate of clearance' ; '(1/min)'});
xlabel({'Weight (kg)'});
xlim( [0.09 100])
ylim( [0.0001 125])
grid on
hold off

% PD oral
subplot(1,3,2)
hold on
set(gca,'xtick',[0.1,1,10,100],'ytick',[0.0001,0.01,1,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log','XScale','log')
title('Volume')
fill([WeightPlotVector(1), WeightPlotVector(end),WeightPlotVector(end),WeightPlotVector(1)],[max(Translation_vd(:,1)) max(Translation_vd(:,end)) min(Translation_vd(:,end)) min(Translation_vd(:,1))], colorID{1},'FaceAlpha',1,'EdgeAlpha',1);
 for i=1:12
plot(IndexBW(i), SubX_MetabolicTranslation.V1(i,1),'.','Color',colorID{i},'MarkerSize',25)
 end
text(0.2,0.02,'Rats (N=10)','FontSize', 20,'FontSmoothing','on') 
text(2,1,'Monkey guess','FontSize', 20,'FontSmoothing','on') 
text(7,2,'Dog guess','FontSize', 20,'FontSmoothing','on') 
ylabel({'Volume scaling' ; '(L)'});
xlabel({'Weight (kg)'});
xlim( [0.09 100])
ylim( [0.0001 125])
grid on
hold off

% PD oral
subplot(1,3,3)
hold on
set(gca,'xtick',[0.1,1,10,100],'ytick',[0.0001,0.01,1,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log','XScale','log')
title('Drug potency')
fill([WeightPlotVector(1), WeightPlotVector(end),WeightPlotVector(end),WeightPlotVector(1)],[max(SpeciesParameters(:,ismember(paramNames,"EC50"))), max(SpeciesParameters(:,ismember(paramNames,"EC50"))), min(SpeciesParameters(:,ismember(paramNames,"EC50"))), min(SpeciesParameters(:,ismember(paramNames,"EC50")))], colorID{1},'FaceAlpha',1,'EdgeAlpha',1);
 for i=1:12
plot(IndexBW(i), SpeciesParameters(i,ismember(paramNames,"EC50")),'.','Color',colorID{i},'MarkerSize',25)
 end
text(0.1,1.5*max(SpeciesParameters(:,ismember(paramNames,"EC50"))),'Rats (N=10)','FontSize', 20,'FontSmoothing','on') 
text(1.9,0.8*min(SpeciesParameters(:,ismember(paramNames,"EC50"))),'Monkey guess','FontSize', 20,'FontSmoothing','on') 
text(7,1.5*max(SpeciesParameters(:,ismember(paramNames,"EC50"))),'Dog guess','FontSize', 20,'FontSmoothing','on') 
ylabel({'(EC50)'});
xlabel({'Weight (kg)'});
xlim( [0.09 100])
ylim( [0.0001 125])
grid on
hold off