%% Declare treatment variables

HumanBW              = 80;        % (kg)
BioavailabilityHuman = 77;        % (%)
ReAdministration_Time   = 1440*2; % (minutes) between re-administrations
ReAdministration_Amount = 50*HumanBW; % (umol)

%% Create index vectors, initial values, and parameter matrix

MonkeyBW = 4.31;
DogBW    = 9.725;
IndexBW  = [BWRats,MonkeyBW,DogBW,HumanBW];
IndexDose  = 80*IndexBW; % 80 umol/kg to umol
Bioavailability = [0.62,0.62,0.62,0.62,0.62,0.62,0.62,0.62,0.62,0.62,0.77,0.52,BioavailabilityHuman/100];

load('OptimisedParams_Step2')

SpeciesParameters(1:12,:)  = OptimisedParams_Step2.PHIR;
SpeciesParameters(13,:)    = OptimisedParams_Step2.PHIR(11,:); % where subject 11 is monkey
SpeciesParameters(:,ismember(paramNames,"BW"))  = IndexBW';
SpeciesParameters(:,ismember(paramNames,"f"))   = Bioavailability';

SpeciesParameters(:,ismember(paramNames,"ReAdministration_Time"))    = ReAdministration_Time;  % minutes between re-administrations
SpeciesParameters(:,ismember(paramNames,"ReAdministration_Amount"))  = ReAdministration_Amount;  % umol

SpeciesStates      = repmat(initialConditions',13,1);
SpeciesStates(:,ismember(stateNames,"A"))  = ReAdministration_Amount;

%% Extract variability from Rat

V1variability   = [1-(2*std(SpeciesParameters(1:10,3))/mean(SpeciesParameters(1:10,3))),1/(1-(2*std(SpeciesParameters(1:10,3))/mean(SpeciesParameters(1:10,3))))]; %95%
CLvariability   = [1-(2*std(SpeciesParameters(1:10,5))/mean(SpeciesParameters(1:10,5))),1/(1-(2*std(SpeciesParameters(1:10,5))/mean(SpeciesParameters(1:10,5))))]; %95%
EC50variability = [1-(2*std(SpeciesParameters(1:10,7))/mean(SpeciesParameters(1:10,7))),1/(1-(2*std(SpeciesParameters(1:10,7))/mean(SpeciesParameters(1:10,7))))]; %95%

%% Simulate clinical testing

count = 1;
for i = 1:2
    SpeciesParameters(13,ismember(paramNames,"V1ref"))  = SpeciesParameters(11,ismember(paramNames,"V1ref"))*V1variability(i); 
    for j = 1:2
            SpeciesParameters(13,ismember(paramNames,"CLref"))  = SpeciesParameters(11,ismember(paramNames,"CLref"))*CLvariability(j);       
        for k = 1:2
                        SpeciesParameters(13,ismember(paramNames,"EC50"))  = SpeciesParameters(11,ismember(paramNames,"EC50"))*EC50variability(j);  

simHuman   = model(0:1:1440*7*4,SpeciesStates(13,:),SpeciesParameters(13,:));

% PK uncertainty
    NewPK  = simHuman.statevalues(:,ismember(simHuman.states,'C1'));
    if count == 1
        maxPK = NewPK;
        minPK = NewPK;
    end
    maxPK  = max(maxPK,NewPK);
    minPK = min(minPK,NewPK);
    % PD uncertainty
    NewPD  = simHuman.statevalues(:,ismember(simHuman.states,'HormoneX'));
    if count == 1
        maxPD = NewPD;
        minPD = NewPD;
    end
    maxPD  = max(maxPD,NewPD);
    minPD = min(minPD,NewPD);
    
    % CL
    NewCL  = simHuman.variablevalues(1,ismember(simHuman.variables,'CL'));
    if count == 1
        maxCL = NewCL;
        minCL = NewCL;
    end
    maxCL  = max(maxCL,NewCL);
    minCL = min(minCL,NewCL);
    % V1
    NewV1  = simHuman.variablevalues(1,ismember(simHuman.variables,'V1'));
    if count == 1
        maxV1 = NewV1;
        minV1 = NewV1;
    end
    maxV1  = max(maxV1,NewV1);
    minV1 = min(minV1,NewV1);
    % EC50
    NewEC50  = SpeciesParameters(13,ismember(paramNames,"EC50"));
    if count == 1
        maxEC50 = NewEC50;
        minEC50 = NewEC50;
    end
    maxEC50  = max(maxEC50,NewEC50);
    minEC50 = min(minEC50,NewEC50);
    
                            
    count = count + 1;
        end
    end
end


%%  PK plot
figure('units','normalized','outerposition',[0 0 1 1])

% PK
subplot(1,2,1)
hold on
set(gca,'ytick',[0.1,1,10,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log')
title('Pharmacokinetics')
yline(600,'r --','LineWidth',2);
fill([simHuman.time(2:end), fliplr(simHuman.time(2:end))]/1440,[maxPK(2:end)', fliplr(minPK(2:end)')], colorID{13},'FaceAlpha',0.7,'EdgeAlpha',1);
ylabel({'SubX (uMol/L)'});
xlabel({'Time (days)'});
ylim( [0.1 1000])
legend('Toxic max limit','Human prediction')
grid on
hold off
% PD
subplot(1,2,2)
hold on
set(gca,'ytick',0:20:100,'FontSize', 20,'FontSmoothing','on','fontname','Arial')
title('Pharmacodynamics')
yline(40,'r --','LineWidth',2);
fill([simHuman.time, fliplr(simHuman.time)]/1440,[maxPD', fliplr(minPD')], colorID{13},'FaceAlpha',0.7,'EdgeAlpha',1);
ylabel({'HormoneX (uMol/L)'});
xlabel({'Time (days)'});
ylim( [0 125])
legend('Hormone max limit','Human prediction')
grid on
hold off



%% 
for i = 1:12

simSpecies   = model(0:1:1,SpeciesStates(i,:),SpeciesParameters(i,:));

SubX_MetabolicTranslation.CL(i,1) = simSpecies.variablevalues(1,ismember(simSpecies.variables,'CL'));
SubX_MetabolicTranslation.V1(i,1) = simSpecies.variablevalues(1,ismember(simSpecies.variables,'V1'));
end

WeightPlotVector = 0.1:0.1:100;
Translation_CL  = OptimisedParams_Step2.PHI(ismember(paramNames,"CLref")) .*(WeightPlotVector./0.3).^OptimisedParams_Step2.PHI(ismember(paramNames,"Rb"));
Translation_V1  = OptimisedParams_Step2.PHI(ismember(paramNames,"V1ref")) .*(WeightPlotVector./0.3).^OptimisedParams_Step2.PHI(ismember(paramNames,"Vb"));

%% Metabolic translation
figure('units','normalized','outerposition',[0 0 1 1])
        
% PD oral
subplot(2,2,1)
hold on
set(gca,'xtick',[0.1,1,10,100],'ytick',[0.0001,0.01,1,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log','XScale','log')
title('Clearance')
plot(WeightPlotVector,Translation_CL,'--','Color', colorID{1},'LineWidth',2);
 for i=1:12
plot(IndexBW(i), SubX_MetabolicTranslation.CL(i,1),'.','Color',colorID{i},'MarkerSize',25)
 end
 fill([HumanBW*0.95, HumanBW*1.05,HumanBW*1.05,HumanBW*0.95],[maxCL,maxCL,minCL,minCL], colorID{13},'FaceAlpha',1,'EdgeAlpha',1,'LineWidth',2);
 text(0.2,0.0005,'Rats (N=10)','FontSize', 20,'FontSmoothing','on')
text(2,0.012,'Monkey','FontSize', 20,'FontSmoothing','on') 
text(7,0.02,'Dog','FontSize', 20,'FontSmoothing','on') 
text(30,maxCL*1.5,'Human','FontSize', 20,'FontSmoothing','on') 
ylabel({'Rate of clearance' ; '(1/min)'});
xlabel({'Weight (kg)'});
xlim( [0.09 100])
grid on
hold off

% PD oral
subplot(2,2,2)
hold on
set(gca,'xtick',[0.1,1,10,100],'ytick',[0.0001,0.01,1,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log','XScale','log')
title('Volume')
plot(WeightPlotVector,Translation_V1,'--','Color', colorID{1},'LineWidth',2);
 for i=1:12
plot(IndexBW(i), SubX_MetabolicTranslation.V1(i,1),'.','Color',colorID{i},'MarkerSize',25)
 end
fill([HumanBW*0.95, HumanBW*1.05,HumanBW*1.05,HumanBW*0.95],[maxV1,maxV1,minV1,minV1], colorID{13},'FaceAlpha',1,'EdgeAlpha',1,'LineWidth',2);
text(30,maxV1*1.5,'Human','FontSize', 20,'FontSmoothing','on') 
 text(0.2,0.02,'Rats (N=10)','FontSize', 20,'FontSmoothing','on')
text(2,1,'Monkey','FontSize', 20,'FontSmoothing','on') 
text(7,2,'Dog','FontSize', 20,'FontSmoothing','on') 
ylabel({'Volume scaling' ; '(L)'});
xlabel({'Weight (kg)'});
xlim( [0.09 100])
grid on
hold off

% PD oral
subplot(2,2,3)
hold on
set(gca,'xtick',[0.1,1,10,100],'ytick',[0.0001,0.01,1,100],'FontSize', 20,'FontSmoothing','on','fontname','Arial','YScale','log','XScale','log')
title('Potency')
yline(OptimisedParams_Step2.PHI(ismember(paramNames,"EC50")),'--','Color', colorID{1},'LineWidth',2);
 for i=1:12
plot(IndexBW(i), SpeciesParameters(i,ismember(paramNames,"EC50")),'.','Color',colorID{i},'MarkerSize',25)
 end
fill([HumanBW*0.9, HumanBW*1.1,HumanBW*1.1,HumanBW*0.9],SpeciesParameters(11,ismember(paramNames,"EC50"))*[EC50variability(1),EC50variability(1),EC50variability(2),EC50variability(2)], colorID{13},'FaceAlpha',1,'EdgeAlpha',1,'LineWidth',2);
text(50,1.5*SpeciesParameters(11,ismember(paramNames,"EC50"))*EC50variability(2),'Human','FontSize', 20,'FontSmoothing','on') 
text(0.1,1.5*max(SpeciesParameters(1:10,ismember(paramNames,"EC50"))),'Rats (N=10)','FontSize', 20,'FontSmoothing','on') 
text(1.9,1.5*max(SpeciesParameters(11,ismember(paramNames,"EC50"))),'Monkey','FontSize', 20,'FontSmoothing','on') 
text(7,1.5*max(SpeciesParameters(12,ismember(paramNames,"EC50"))),'Dog','FontSize', 20,'FontSmoothing','on') 
ylabel({'(EC50)'});
xlabel({'Weight (kg)'});
xlim( [0.09 100])
ylim( [0.1 100])
grid on
hold off

% PD oral
subplot(2,2,4)
hold on
set(gca,'xtick',[0.1,1,10,100],'ytick',0:20:100,'FontSize', 20,'FontSmoothing','on','fontname','Arial','XScale','log')
title('Bioavailability')
for i=1:13
plot(IndexBW(i), 100*Bioavailability(i),'.','Color',colorID{i},'MarkerSize',25)
 end
text(30 ,1.2*100*Bioavailability(13),'Human','FontSize', 20,'FontSmoothing','on') 
text(0.1,1.2*100*Bioavailability(1) ,'Rats (N=10)','FontSize', 20,'FontSmoothing','on') 
text(1.9,1.2*100*Bioavailability(11),'Monkey','FontSize', 20,'FontSmoothing','on') 
text(7  ,1.2*100*Bioavailability(12),'Dog','FontSize', 20,'FontSmoothing','on') 
ylabel({'(%)'});
xlabel({'Weight (kg)'});
xlim( [0.09 100])
ylim( [0.0001 125])
grid on
hold off